@@ -1,15 +1,19 @@
 from autoarray import preprocess
-from autoarray.dataset.imaging import WTildeImaging
-from autoarray.dataset.imaging import Imaging, SettingsImaging
-from autoarray.dataset.interferometer import Interferometer, SettingsInterferometer
+from autoarray.dataset.imaging.w_tilde import WTildeImaging
+from autoarray.dataset.imaging.imaging import Imaging, SettingsImaging
+from autoarray.dataset.interferometer.interferometer import (
+    Interferometer,
+    SettingsInterferometer,
+)
 from autoarray.mask.mask_1d import Mask1D
 from autoarray.mask.mask_2d import Mask2D
 from autoarray.operators.convolver import Convolver
-from autoarray.inversion import pixelizations as pix
+from autoarray.inversion.pixelization import mesh
 from autoarray.inversion import regularization as reg
-from autoarray.inversion.pixelizations.abstract import AbstractPixelization
+from autoarray.inversion.pixelization.mesh.abstract import AbstractMesh
 from autoarray.inversion.regularization.abstract import AbstractRegularization
-from autoarray.inversion.pixelizations.settings import SettingsPixelization
+from autoarray.inversion.pixelization.pixelization import Pixelization
+from autoarray.inversion.pixelization.settings import SettingsPixelization
 from autoarray.inversion.inversion.settings import SettingsInversion
 from autoarray.inversion.inversion.factory import inversion_from as Inversion
 from autoarray.inversion.inversion.factory import (
@@ -18,20 +22,23 @@ from autoarray.inversion.inversion.factory import (
 from autoarray.inversion.inversion.factory import (
     inversion_interferometer_unpacked_from as InversionInterferometer,
 )
-from autoarray.inversion.mappers.factory import mapper_from as Mapper
+from autoarray.inversion.pixelization.mappers.abstract import AbstractMapper
+from autoarray.inversion.pixelization.mappers.mapper_grids import MapperGrids
+from autoarray.inversion.pixelization.mappers.factory import mapper_from as Mapper
 from autoarray.operators.transformer import TransformerDFT
 from autoarray.operators.transformer import TransformerNUFFT
 from autoarray.structures.arrays.uniform_1d import Array1D
 from autoarray.structures.arrays.uniform_2d import Array2D
-from autoarray.structures.values import ValuesIrregular
+from autoarray.structures.arrays.irregular import ArrayIrregular
 from autoarray.structures.grids.uniform_1d import Grid1D
 from autoarray.structures.grids.uniform_2d import Grid2D
 from autoarray.structures.grids.sparse_2d import Grid2DSparse
 from autoarray.structures.grids.iterate_2d import Grid2DIterate
 from autoarray.structures.grids.irregular_2d import Grid2DIrregular
 from autoarray.structures.grids.irregular_2d import Grid2DIrregularUniform
-from autoarray.structures.grids.grid_2d_pixelization import Grid2DRectangular
-from autoarray.structures.grids.grid_2d_pixelization import Grid2DVoronoi
+from autoarray.structures.mesh.rectangular_2d import Mesh2DRectangular
+from autoarray.structures.mesh.voronoi_2d import Mesh2DVoronoi
+from autoarray.structures.mesh.delaunay_2d import Mesh2DDelaunay
 from autoarray.structures.vectors.uniform import VectorYX2D
 from autoarray.structures.vectors.irregular import VectorYX2DIrregular
 from autoarray.structures.arrays.kernel_2d import Kernel2D
@@ -41,27 +48,32 @@ from autoarray.structures.visibilities import VisibilitiesNoiseMap
 from autogalaxy import cosmology as cosmo
 from autogalaxy.gui.clicker import Clicker
 from autogalaxy.gui.scribbler import Scribbler
-from autogalaxy.galaxy.galaxy import Galaxy, HyperGalaxy, Redshift
+from autogalaxy.galaxy.galaxy import Galaxy
+from autogalaxy.galaxy.hyper import HyperGalaxy
+from autogalaxy.galaxy.redshift import Redshift
 from autogalaxy.analysis.clump_model import ClumpModel
 from autogalaxy.analysis.clump_model import ClumpModelDisabled
 
 from autogalaxy.quantity.dataset_quantity import DatasetQuantity
+from autogalaxy.quantity.dataset_quantity import SettingsQuantity
 from autogalaxy.hyper import hyper_data
 from autogalaxy.plane.plane import Plane
 from autogalaxy.profiles.geometry_profiles import EllProfile
 from autogalaxy.profiles import (
     point_sources as ps,
-    light_profiles as lp,
-    mass_profiles as mp,
+    mass as mp,
     light_and_mass_profiles as lmp,
     scaling_relations as sr,
 )
-from autogalaxy.profiles.light_profiles import light_profiles_init as lp_init
-from autogalaxy.profiles.light_profiles import light_profiles_snr as lp_snr
-from autogalaxy.profiles.light_profiles import light_profiles_linear as lp_linear
-from autogalaxy.profiles.light_profiles import light_profiles_operated as lp_operated
-from autogalaxy.profiles.light_profiles import (
-    light_profiles_linear_operated as lp_linear_operated,
+from autogalaxy.profiles.light.abstract import LightProfile
+from autogalaxy.profiles.light import standard as lp
+from autogalaxy.profiles.light import snr as lp_snr
+from autogalaxy.profiles.light import linear as lp_linear
+from autogalaxy.profiles.light import shapelets as lp_shapelets
+from autogalaxy.profiles.light import operated as lp_operated
+from autogalaxy.profiles.light import basis as lp_basis
+from autogalaxy.profiles.light import (
+    linear_operated as lp_linear_operated,
 )
 from autogalaxy.operate.image import OperateImage
 from autogalaxy.operate.deflections import OperateDeflections
@@ -104,4 +116,4 @@ from autoconf import conf
 
 conf.instance.register(__file__)
 
-__version__ = "2022.07.11.1"
+__version__ = "2023.3.21.5"
\ No newline at end of file
