@@ -1,4 +1,4 @@
-import copy
+import os
 import json
 import logging
 import numpy as np
@@ -21,6 +21,7 @@ from autolens.analysis.positions import PositionsLHResample
 from autolens.analysis.positions import PositionsLHPenalty
 from autolens.analysis.visualizer import Visualizer
 from autolens.lens.ray_tracing import Tracer
+from autolens.lens.to_inversion import TracerToInversion
 from autolens.analysis.settings import SettingsLens
 
 from autolens.lens import ray_tracing_util
@@ -94,7 +95,7 @@ class AnalysisLensing:
             subhalo_centre = ray_tracing_util.grid_2d_at_redshift_from(
                 galaxies=instance.galaxies,
                 redshift=instance.galaxies.subhalo.redshift,
-                grid=aa.Grid2DIrregular(grid=[instance.galaxies.subhalo.mass.centre]),
+                grid=aa.Grid2DIrregular(values=[instance.galaxies.subhalo.mass.centre]),
                 cosmology=self.cosmology,
             )
 
@@ -223,6 +224,10 @@ class AnalysisDataset(AgAnalysisDataset, AnalysisLensing):
             raise_inversion_positions_likelihood_exception
         )
 
+        if os.environ.get("PYAUTOFIT_TEST_MODE") == "1":
+
+            self.raise_inversion_positions_likelihood_exception = False
+
     def modify_before_fit(self, paths: af.DirectoryPaths, model: af.Collection):
         """
         PyAutoFit calls this function immediately before the non-linear search begins, therefore it can be used to
@@ -231,7 +236,7 @@ class AnalysisDataset(AgAnalysisDataset, AnalysisLensing):
         This function:
 
         - Checks that the hyper-dataset is consistent with previous hyper-datasets if the model-fit is being
-        resumed from a previous run.
+          resumed from a previous run.
 
         - Checks the model and raises exceptions if certain critieria are not met.
 
@@ -247,9 +252,9 @@ class AnalysisDataset(AgAnalysisDataset, AnalysisLensing):
             the imaging data.
         """
 
-        self.raise_exceptions(model=model)
+        super().modify_before_fit(paths=paths, model=model)
 
-        self.check_and_replace_hyper_images(paths=paths)
+        self.raise_exceptions(model=model)
 
     def raise_exceptions(self, model):
 
@@ -257,6 +262,9 @@ class AnalysisDataset(AgAnalysisDataset, AnalysisLensing):
             if (
                 self.positions_likelihood is None
                 and self.raise_inversion_positions_likelihood_exception
+                and not conf.instance["general"]["test"][
+                    "disable_positions_lh_inversion_check"
+                ]
             ):
                 raise exc.AnalysisException(
                     "You have begun a model-fit which reconstructs the source using a pixelization.\n\n"
@@ -330,7 +338,7 @@ class AnalysisDataset(AgAnalysisDataset, AnalysisLensing):
         For this analysis it outputs the following:
 
         - The stochastic log likelihoods of a pixelization, provided the pixelization has functionality that can
-        compute likelihoods for different KMeans seeds and grids (e.g. `VoronoiBrightnessImage).
+          compute likelihoods for different KMeans seeds and grids (e.g. `VoronoiBrightnessImage).
 
         Parameters
         ----------
@@ -340,24 +348,23 @@ class AnalysisDataset(AgAnalysisDataset, AnalysisLensing):
         result
             The result of a lens model fit, including the non-linear search, samples and maximum likelihood tracer.
         """
-        pixelization = ag.util.model.pixelization_from(model=result.model)
 
-        if pixelization is not None:
+        mesh_list = ag.util.model.mesh_list_from(model=result.model)
 
-            tracer = result.max_log_likelihood_tracer
-
-            sparse_image_plane_grid_pg_list = tracer.to_inversion.sparse_image_plane_grid_pg_list_from(
-                grid=self.dataset.grid_pixelized
-            )
+        if len(mesh_list) > 0:
 
             paths.save_object(
-                "preload_sparse_grids_of_planes", sparse_image_plane_grid_pg_list
+                "preload_sparse_grids_of_planes",
+                result.max_log_likelihood_fit.tracer_to_inversion.sparse_image_plane_grid_pg_list,
             )
 
         if conf.instance["general"]["hyper"]["stochastic_outputs"]:
-            if pixelization is not None:
-                if pixelization.is_stochastic:
-                    self.save_stochastic_outputs(paths=paths, samples=result.samples)
+            if len(mesh_list) > 0:
+                for mesh in mesh_list:
+                    if mesh.is_stochastic:
+                        self.save_stochastic_outputs(
+                            paths=paths, samples=result.samples
+                        )
 
     def save_stochastic_outputs(self, paths: af.DirectoryPaths, samples: af.Samples):
         """
@@ -389,9 +396,9 @@ class AnalysisDataset(AgAnalysisDataset, AnalysisLensing):
             with open(stochastic_log_likelihoods_json_file, "r") as f:
                 stochastic_log_likelihoods = np.asarray(json.load(f))
         except FileNotFoundError:
-            instance = samples.max_log_likelihood_instance
-            stochastic_log_likelihoods = self.stochastic_log_likelihoods_via_instance_from(
-                instance=instance
+            instance = samples.max_log_likelihood()
+            stochastic_log_likelihoods = (
+                self.stochastic_log_likelihoods_via_instance_from(instance=instance)
             )
 
         if stochastic_log_likelihoods is None:
