@@ -1,9 +1,7 @@
 import logging
 import numpy as np
-from os import path
 from typing import Dict, Optional, List
 
-import autofit as af
 import autoarray as aa
 import autogalaxy as ag
 
@@ -24,6 +22,9 @@ class Preloads(ag.Preloads):
         mapper_list: Optional[aa.AbstractMapper] = None,
         mapper_galaxy_dict: Optional[Dict[aa.AbstractMapper, ag.Galaxy]] = None,
         operated_mapping_matrix: Optional[np.ndarray] = None,
+        linear_func_operated_mapping_matrix_dict=None,
+        linear_func_weighted_mapping_vectors_dict=None,
+        linear_func_curvature_vectors_dict=None,
         curvature_matrix_preload: Optional[np.ndarray] = None,
         curvature_matrix_counts: Optional[np.ndarray] = None,
         regularization_matrix: Optional[np.ndarray] = None,
@@ -92,6 +93,9 @@ class Preloads(ag.Preloads):
             mapper_list=mapper_list,
             mapper_galaxy_dict=mapper_galaxy_dict,
             operated_mapping_matrix=operated_mapping_matrix,
+            linear_func_operated_mapping_matrix_dict=linear_func_operated_mapping_matrix_dict,
+            linear_func_weighted_mapping_vectors_dict=linear_func_weighted_mapping_vectors_dict,
+            linear_func_curvature_vectors_dict=linear_func_curvature_vectors_dict,
             curvature_matrix_preload=curvature_matrix_preload,
             curvature_matrix_counts=curvature_matrix_counts,
             regularization_matrix=regularization_matrix,
@@ -135,11 +139,11 @@ class Preloads(ag.Preloads):
 
         if preloads.mapper_list is not None:
 
-            preloads.mapper_galaxy_dict = fit_0.tracer.to_inversion.mapper_galaxy_dict_from(
-                grid=fit_0.dataset.grid_pixelized
-            )
+            preloads.mapper_galaxy_dict = fit_0.tracer_to_inversion.mapper_galaxy_dict
 
         preloads.set_operated_mapping_matrix_with_preloads(fit_0=fit_0, fit_1=fit_1)
+        preloads.set_linear_func_inversion_dicts(fit_0=fit_0, fit_1=fit_1)
+        preloads.set_curvature_matrix(fit_0=fit_0, fit_1=fit_1)
         preloads.set_regularization_matrix_and_term(fit_0=fit_0, fit_1=fit_1)
 
         return preloads
@@ -167,11 +171,11 @@ class Preloads(ag.Preloads):
         self.traced_grids_of_planes_for_inversion = None
 
         traced_grids_of_planes_0 = fit_0.tracer.traced_grid_2d_list_from(
-            grid=fit_0.dataset.grid_pixelized
+            grid=fit_0.dataset.grid_pixelization
         )
 
         traced_grids_of_planes_1 = fit_1.tracer.traced_grid_2d_list_from(
-            grid=fit_1.dataset.grid_pixelized
+            grid=fit_1.dataset.grid_pixelization
         )
 
         if traced_grids_of_planes_0[-1] is not None:
@@ -216,12 +220,12 @@ class Preloads(ag.Preloads):
 
         self.sparse_image_plane_grid_pg_list = None
 
-        sparse_image_plane_grid_pg_list_0 = fit_0.tracer.to_inversion.sparse_image_plane_grid_pg_list_from(
-            grid=fit_0.dataset.grid_pixelized
+        sparse_image_plane_grid_pg_list_0 = (
+            fit_0.tracer_to_inversion.sparse_image_plane_grid_pg_list
         )
 
-        sparse_image_plane_grid_pg_list_1 = fit_1.tracer.to_inversion.sparse_image_plane_grid_pg_list_from(
-            grid=fit_1.dataset.grid_pixelized
+        sparse_image_plane_grid_pg_list_1 = (
+            fit_1.tracer_to_inversion.sparse_image_plane_grid_pg_list
         )
 
         if sparse_image_plane_grid_pg_list_0[-1] is not None:
@@ -263,6 +267,10 @@ class Preloads(ag.Preloads):
         self.relocated_grid = None
         self.mapper = None
         self.blurred_mapping_matrix = None
+        self.curvature_matrix = None
+        self.linear_func_operated_mapping_matrix_dict = None
+        self.linear_func_weighted_mapping_vectors_dict = None
+        self.linear_func_curvature_vectors_dict = None
         self.curvature_matrix_preload = None
         self.curvature_matrix_counts = None
         self.regularization_matrix = None
@@ -291,9 +299,16 @@ class Preloads(ag.Preloads):
         line += [
             f"Blurred Mapping Matrix = {self.operated_mapping_matrix is not None}\n"
         ]
+        line += [
+            f"Inversion Linear Func (Linear Light Profile) Dicts = {self.linear_func_weighted_mapping_vectors_dict is not None}\n"
+        ]
         line += [
             f"Curvature Matrix Sparse = {self.curvature_matrix_preload is not None}\n"
         ]
+        line += [f"Curvature Matrix = {self.curvature_matrix is not None}\n"]
+        line += [
+            f"Curvature Matrix Mapper Diag = {self.curvature_matrix_mapper_diag is not None}\n"
+        ]
         line += [f"Regularization Matrix = {self.regularization_matrix is not None}\n"]
         line += [
             f"Log Det Regularization Matrix Term = {self.log_det_regularization_matrix_term is not None}\n"
