@@ -4,19 +4,19 @@ from autogalaxy.fixtures import *
 
 
 def make_positions_x2():
-    return al.Grid2DIrregular(grid=[(1.0, 1.0), (2.0, 2.0)])
+    return al.Grid2DIrregular(values=[(1.0, 1.0), (2.0, 2.0)])
 
 
 def make_positions_noise_map_x2():
-    return al.ValuesIrregular(values=[1.0, 1.0])
+    return al.ArrayIrregular(values=[1.0, 1.0])
 
 
 def make_fluxes_x2():
-    return al.ValuesIrregular(values=[1.0, 2.0])
+    return al.ArrayIrregular(values=[1.0, 2.0])
 
 
 def make_fluxes_noise_map_x2():
-    return al.ValuesIrregular(values=[1.0, 1.0])
+    return al.ArrayIrregular(values=[1.0, 1.0])
 
 
 def make_point_dataset():
@@ -53,12 +53,12 @@ def make_tracer_x2_plane_7x7():
 
 def make_tracer_x2_plane_inversion_7x7():
 
-    source_gal_inversion = al.Galaxy(
-        redshift=1.0,
-        pixelization=al.pix.Rectangular(),
-        regularization=al.reg.Constant(),
+    pixelization = al.Pixelization(
+        mesh=al.mesh.Rectangular(), regularization=al.reg.Constant()
     )
 
+    source_gal_inversion = al.Galaxy(redshift=1.0, pixelization=pixelization)
+
     return al.Tracer.from_galaxies(
         galaxies=[make_gal_x1_mp(), make_gal_x1_lp(), source_gal_inversion]
     )
@@ -66,12 +66,12 @@ def make_tracer_x2_plane_inversion_7x7():
 
 def make_tracer_x2_plane_voronoi_7x7():
 
-    source_gal_inversion = al.Galaxy(
-        redshift=1.0,
-        pixelization=al.pix.VoronoiMagnification(),
-        regularization=al.reg.Constant(),
+    pixelization = al.Pixelization(
+        mesh=al.mesh.VoronoiMagnification(), regularization=al.reg.Constant()
     )
 
+    source_gal_inversion = al.Galaxy(redshift=1.0, pixelization=pixelization)
+
     return al.Tracer.from_galaxies(
         galaxies=[make_gal_x1_mp(), make_gal_x1_lp(), source_gal_inversion]
     )
