@@ -39,7 +39,7 @@ class AnalysisImaging(AnalysisDataset):
         This function:
 
         - Checks that the hyper-dataset is consistent with previous hyper-datasets if the model-fit is being
-        resumed from a previous run.
+          resumed from a previous run.
 
         - Checks the model and raises exceptions if certain critieria are not met.
 
@@ -58,21 +58,23 @@ class AnalysisImaging(AnalysisDataset):
 
         if not paths.is_complete:
 
-            visualizer = VisualizerImaging(visualize_path=paths.image_path)
+            if not os.environ.get("PYAUTOFIT_TEST_MODE") == "1":
 
-            visualizer.visualize_imaging(imaging=self.imaging)
+                visualizer = VisualizerImaging(visualize_path=paths.image_path)
 
-            if self.positions_likelihood is not None:
-                visualizer.visualize_image_with_positions(
-                    image=self.imaging.image,
-                    positions=self.positions_likelihood.positions,
+                visualizer.visualize_imaging(imaging=self.imaging)
+
+                if self.positions_likelihood is not None:
+                    visualizer.visualize_image_with_positions(
+                        image=self.imaging.image,
+                        positions=self.positions_likelihood.positions,
+                    )
+
+                visualizer.visualize_hyper_images(
+                    hyper_galaxy_image_path_dict=self.hyper_galaxy_image_path_dict,
+                    hyper_model_image=self.hyper_model_image,
                 )
 
-            visualizer.visualize_hyper_images(
-                hyper_galaxy_image_path_dict=self.hyper_galaxy_image_path_dict,
-                hyper_model_image=self.hyper_model_image,
-            )
-
             self.set_preloads(paths=paths, model=model)
 
         return self
@@ -87,17 +89,17 @@ class AnalysisImaging(AnalysisDataset):
         For this analysis class, this function performs the following steps:
 
         1) If the analysis has a hyper dataset, associated the model galaxy images of this dataset to the galaxies in
-        the model instance.
+           the model instance.
 
         2) Extract attributes which model aspects of the data reductions, like the scaling the background sky
-        and background noise.
+           and background noise.
 
         3) Extracts all galaxies from the model instance and set up a `Tracer`, which includes ordering the galaxies
-        by redshift to set up each `Plane`.
+           by redshift to set up each `Plane`.
 
         4) Use the `Tracer` and other attributes to create a `FitImaging` object, which performs steps such as creating
-        model images of every galaxy in the tracer, blurring them with the imaging dataset's PSF and computing
-        residuals, a chi-squared statistic and the log likelihood.
+           model images of every galaxy in the tracer, blurring them with the imaging dataset's PSF and computing
+           residuals, a chi-squared statistic and the log likelihood.
 
         Certain models will fail to fit the dataset and raise an exception. For example if an `Inversion` is used, the
         linear algebra calculation may be invalid and raise an Exception. In such circumstances the model is discarded
@@ -135,6 +137,7 @@ class AnalysisImaging(AnalysisDataset):
             exc.PixelizationException,
             exc.InversionException,
             exc.GridException,
+            exc.MeshException,
             ValueError,
             TypeError,
             np.linalg.LinAlgError,
@@ -302,7 +305,7 @@ class AnalysisImaging(AnalysisDataset):
 
         info_dict["image_pixels"] = self.imaging.grid.sub_shape_slim
         info_dict["sub_size_light_profiles"] = self.imaging.grid.sub_size
-        info_dict["sub_size_pixelized"] = self.imaging.grid_pixelized.sub_size
+        info_dict["sub_size_pixelization"] = self.imaging.grid_pixelization.sub_size
         info_dict["psf_shape_2d"] = self.imaging.psf.shape_native
 
         if fit.inversion is not None:
@@ -356,11 +359,11 @@ class AnalysisImaging(AnalysisDataset):
         instance = self.instance_with_associated_hyper_images_from(instance=instance)
         tracer = self.tracer_via_instance_from(instance=instance)
 
-        if not tracer.has(cls=ag.pix.Pixelization):
+        if not tracer.has(cls=ag.Pixelization):
             return
 
         if not any(
-            [pix.is_stochastic for pix in tracer.cls_list_from(cls=ag.pix.Pixelization)]
+            pix.mesh.is_stochastic for pix in tracer.cls_list_from(cls=ag.Pixelization)
         ):
             return
 
@@ -379,6 +382,7 @@ class AnalysisImaging(AnalysisDataset):
         for i in range(self.settings_lens.stochastic_samples):
 
             try:
+
                 log_evidence = FitImaging(
                     dataset=self.dataset,
                     tracer=tracer,
@@ -418,13 +422,13 @@ class AnalysisImaging(AnalysisDataset):
         - Images of the best-fit `Tracer`, including the images of each of its galaxies.
 
         - Images of the best-fit `FitImaging`, including the model-image, residuals and chi-squared of its fit to
-        the imaging data.
+          the imaging data.
 
         - The hyper-images of the model-fit showing how the hyper galaxies are used to represent different galaxies in
-        the dataset.
+          the dataset.
 
         - If hyper features are used to scale the noise or background sky, a `FitImaging` with these features turned
-        off may be output, to indicate how much these features are altering the dataset.
+          off may be output, to indicate how much these features are altering the dataset.
 
         The images output by this function are customized using the file `config/visualize/plots.ini`.
 
@@ -441,6 +445,9 @@ class AnalysisImaging(AnalysisDataset):
             which may change which images are output.
         """
 
+        if os.environ.get("PYAUTOFIT_TEST_MODE") == "1":
+            return
+
         instance = self.instance_with_associated_hyper_images_from(instance=instance)
 
         fit = self.fit_imaging_via_instance_from(instance=instance)
@@ -458,12 +465,18 @@ class AnalysisImaging(AnalysisDataset):
 
         visualizer = VisualizerImaging(visualize_path=paths.image_path)
 
-        visualizer.visualize_fit_imaging(fit=fit, during_analysis=during_analysis)
+        try:
+            visualizer.visualize_fit_imaging(fit=fit, during_analysis=during_analysis)
+        except exc.InversionException:
+            pass
+
+        tracer = fit.tracer_linear_light_profiles_to_light_profiles
+
         visualizer.visualize_tracer(
-            tracer=fit.tracer, grid=fit.grid, during_analysis=during_analysis
+            tracer=tracer, grid=fit.grid, during_analysis=during_analysis
         )
         visualizer.visualize_galaxies(
-            galaxies=fit.tracer.galaxies, grid=fit.grid, during_analysis=during_analysis
+            galaxies=tracer.galaxies, grid=fit.grid, during_analysis=during_analysis
         )
         if fit.inversion is not None:
             visualizer.visualize_inversion(
@@ -481,13 +494,16 @@ class AnalysisImaging(AnalysisDataset):
                 preload_overwrite=Preloads(use_w_tilde=False),
             )
 
-            visualizer.visualize_fit_imaging(
-                fit=fit, during_analysis=during_analysis, subfolders="fit_no_hyper"
-            )
+            try:
+                visualizer.visualize_fit_imaging(
+                    fit=fit, during_analysis=during_analysis, subfolders="fit_no_hyper"
+                )
+            except exc.InversionException:
+                pass
 
     def make_result(
         self,
-        samples: af.PDFSamples,
+        samples: af.SamplesPDF,
         model: af.Collection,
         sigma=1.0,
         use_errors=True,
@@ -497,10 +513,10 @@ class AnalysisImaging(AnalysisDataset):
         After the non-linear search is complete create its `Result`, which includes:
 
         - The samples of the non-linear search (E.g. MCMC chains, nested sampling samples) which are used to compute
-        the maximum likelihood model, posteriors and other properties.
+          the maximum likelihood model, posteriors and other properties.
 
         - The model used to fit the data, which uses the samples to create specific instances of the model (e.g.
-        an instance of the maximum log likelihood model).
+          an instance of the maximum log likelihood model).
 
         - The non-linear search used to perform the model fit.
 
@@ -544,8 +560,8 @@ class AnalysisImaging(AnalysisDataset):
         - Its mask.
         - The positions of the brightest pixels in the lensed source which are used to discard mass models.
         - The preloaded image-plane source plane pixelization if used by the analysis. This ensures that differences in
-        the scikit-learn library do not lead to different pixelizations being computed if results are transferred from
-        a HPC to laptop.
+          the scikit-learn library do not lead to different pixelizations being computed if results are transferred from
+          a HPC to laptop.
 
         It is common for these attributes to be loaded by many of the template aggregator functions given in the
         `aggregator` modules. For example, when using the database tools to perform a fit, the default behaviour is for
@@ -560,6 +576,6 @@ class AnalysisImaging(AnalysisDataset):
         """
         super().save_attributes_for_aggregator(paths=paths)
 
-        paths.save_object("psf", self.dataset.psf_unormalized)
+        paths.save_object("psf", self.dataset.psf)
         paths.save_object("mask", self.dataset.mask)
         paths.save_object("positions_likelihood", self.positions_likelihood)
