@@ -1,5 +1,6 @@
 import logging
 import numpy as np
+import os
 from typing import Optional, Union
 
 import autofit as af
@@ -127,21 +128,23 @@ class AnalysisInterferometer(AnalysisDataset):
 
         if not paths.is_complete:
 
-            visualizer = VisualizerInterferometer(visualize_path=paths.image_path)
+            if not os.environ.get("PYAUTOFIT_TEST_MODE") == "1":
 
-            visualizer.visualize_interferometer(interferometer=self.interferometer)
+                visualizer = VisualizerInterferometer(visualize_path=paths.image_path)
 
-            if self.positions_likelihood is not None:
-                visualizer.visualize_image_with_positions(
-                    image=self.interferometer.dirty_image,
-                    positions=self.positions_likelihood.positions,
+                visualizer.visualize_interferometer(interferometer=self.interferometer)
+
+                if self.positions_likelihood is not None:
+                    visualizer.visualize_image_with_positions(
+                        image=self.interferometer.dirty_image,
+                        positions=self.positions_likelihood.positions,
+                    )
+
+                visualizer.visualize_hyper_images(
+                    hyper_galaxy_image_path_dict=self.hyper_galaxy_image_path_dict,
+                    hyper_model_image=self.hyper_model_image,
                 )
 
-            visualizer.visualize_hyper_images(
-                hyper_galaxy_image_path_dict=self.hyper_galaxy_image_path_dict,
-                hyper_model_image=self.hyper_model_image,
-            )
-
             logger.info(
                 "PRELOADS - Setting up preloads, may take a few minutes for fits using an inversion."
             )
@@ -210,9 +213,9 @@ class AnalysisInterferometer(AnalysisDataset):
             ):
                 if galaxy_path in self.hyper_galaxy_visibilities_path_dict:
                     galaxy.hyper_model_visibilities = self.hyper_model_visibilities
-                    galaxy.hyper_galaxy_visibilities = self.hyper_galaxy_visibilities_path_dict[
-                        galaxy_path
-                    ]
+                    galaxy.hyper_galaxy_visibilities = (
+                        self.hyper_galaxy_visibilities_path_dict[galaxy_path]
+                    )
 
         return instance
 
@@ -226,17 +229,17 @@ class AnalysisInterferometer(AnalysisDataset):
         For this analysis class, this function performs the following steps:
 
         1) If the analysis has a hyper dataset, associated the model galaxy images of this dataset to the galaxies in
-        the model instance.
+           the model instance.
 
         2) Extract attributes which model aspects of the data reductions, like the scaling the background sky
-        and background noise.
+           and background noise.
 
         3) Extracts all galaxies from the model instance and set up a `Tracer`, which includes ordering the galaxies
-        by redshift to set up each `Plane`.
+           by redshift to set up each `Plane`.
 
         4) Use the `Tracer` and other attributes to create a `FitInterferometer` object, which performs steps such as
-        creating model images of every galaxy in the plane, transforming them to the uv-plane via a Fourier transform
-        and computing residuals, a chi-squared statistic and the log likelihood.
+           creating model images of every galaxy in the plane, transforming them to the uv-plane via a Fourier transform
+           and computing residuals, a chi-squared statistic and the log likelihood.
 
         Certain models will fail to fit the dataset and raise an exception. For example if an `Inversion` is used, the
         linear algebra calculation may be invalid and raise an Exception. In such circumstances the model is discarded
@@ -256,8 +259,8 @@ class AnalysisInterferometer(AnalysisDataset):
         """
 
         try:
-            log_likelihood_positions_overwrite = self.log_likelihood_positions_overwrite_from(
-                instance=instance
+            log_likelihood_positions_overwrite = (
+                self.log_likelihood_positions_overwrite_from(instance=instance)
             )
             if log_likelihood_positions_overwrite is not None:
                 return log_likelihood_positions_overwrite
@@ -378,37 +381,40 @@ class AnalysisInterferometer(AnalysisDataset):
 
     def stochastic_log_likelihoods_via_instance_from(self, instance):
         """
-        Certain `Inversion`'s have stochasticity in their log likelihood estimate.
+         Certain `Inversion`'s have stochasticity in their log likelihood estimate.
 
-        For example, the `VoronoiBrightnessImage` pixelization, which changes the likelihood depending on how different
-        KMeans seeds change the pixel-grid.
+         For example, the `VoronoiBrightnessImage` pixelization, which changes the likelihood depending on how different
+         KMeans seeds change the pixel-grid.
 
-        A log likelihood cap can be applied to model-fits performed using these `Inversion`'s to improve error and
-        posterior estimates. This log likelihood cap is estimated from a list of stochastic log likelihoods, where
-        these log likelihoods are computed using the same model but with different KMeans seeds.
+         A log likelihood cap can be applied to model-fits performed using these `Inversion`'s to improve error and
+         posterior estimates. This log likelihood cap is estimated from a list of stochastic log likelihoods, where
+         these log likelihoods are computed using the same model but with different KMeans seeds.
 
-        This function computes these stochastic log likelihoods by iterating over many model-fits using different
-        KMeans seeds.
+         This function computes these stochastic log likelihoods by iterating over many model-fits using different
+         KMeans seeds.
 
-        Parameters
-        ----------
-       instance
-            The maximum log likelihood instance of a model that is has finished being fitted to the dataset.
+         Parameters
+         ----------
+        instance
+             The maximum log likelihood instance of a model that is has finished being fitted to the dataset.
 
-        Returns
-        -------
-        float
-            A log likelihood cap which is applied in a stochastic model-fit to give improved error and posterior
-            estimates.
+         Returns
+         -------
+         float
+             A log likelihood cap which is applied in a stochastic model-fit to give improved error and posterior
+             estimates.
         """
         instance = self.instance_with_associated_hyper_images_from(instance=instance)
         tracer = self.tracer_via_instance_from(instance=instance)
 
-        if not tracer.has(cls=aa.pix.Pixelization):
+        if not tracer.has(cls=aa.Pixelization):
             return None
 
         if not any(
-            [pix.is_stochastic for pix in tracer.cls_list_from(cls=ag.pix.Pixelization)]
+            [
+                pix.mesh.is_stochastic
+                for pix in tracer.cls_list_from(cls=ag.Pixelization)
+            ]
         ):
             return
 
@@ -458,13 +464,13 @@ class AnalysisInterferometer(AnalysisDataset):
         - Images of the best-fit `Tracer`, including the images of each of its galaxies.
 
         - Images of the best-fit `FitInterferometer`, including the model-image, residuals and chi-squared of its fit
-        to the imaging data.
+          to the imaging data.
 
         - The hyper-images of the model-fit showing how the hyper galaxies are used to represent different galaxies in
-        the dataset.
+          the dataset.
 
         - If hyper features are used to scale the noise, a `FitInterferometer` with these features turned off may be
-        output, to indicate how much these features are altering the dataset.
+          output, to indicate how much these features are altering the dataset.
 
         The images output by this function are customized using the file `config/visualize/plots.ini`.
 
@@ -480,6 +486,10 @@ class AnalysisInterferometer(AnalysisDataset):
             If True the visualization is being performed midway through the non-linear search before it is finished,
             which may change which images are output.
         """
+
+        if os.environ.get("PYAUTOFIT_TEST_MODE") == "1":
+            return
+
         instance = self.instance_with_associated_hyper_images_from(instance=instance)
 
         fit = self.fit_interferometer_via_instance_from(instance=instance)
@@ -497,14 +507,20 @@ class AnalysisInterferometer(AnalysisDataset):
 
         visualizer = VisualizerInterferometer(visualize_path=paths.image_path)
 
-        visualizer.visualize_fit_interferometer(
-            fit=fit, during_analysis=during_analysis
-        )
+        try:
+            visualizer.visualize_fit_interferometer(
+                fit=fit, during_analysis=during_analysis
+            )
+        except exc.InversionException:
+            pass
+
+        tracer = fit.tracer_linear_light_profiles_to_light_profiles
+
         visualizer.visualize_tracer(
-            tracer=fit.tracer, grid=fit.grid, during_analysis=during_analysis
+            tracer=tracer, grid=fit.grid, during_analysis=during_analysis
         )
         visualizer.visualize_galaxies(
-            galaxies=fit.tracer.galaxies, grid=fit.grid, during_analysis=during_analysis
+            galaxies=tracer.galaxies, grid=fit.grid, during_analysis=during_analysis
         )
         if fit.inversion is not None:
             try:
@@ -524,13 +540,16 @@ class AnalysisInterferometer(AnalysisDataset):
                 preload_overwrite=Preloads(use_w_tilde=False),
             )
 
-            visualizer.visualize_fit_interferometer(
-                fit=fit, during_analysis=during_analysis, subfolders="fit_no_hyper"
-            )
+            try:
+                visualizer.visualize_fit_interferometer(
+                    fit=fit, during_analysis=during_analysis, subfolders="fit_no_hyper"
+                )
+            except exc.InversionException:
+                pass
 
     def make_result(
         self,
-        samples: af.PDFSamples,
+        samples: af.SamplesPDF,
         model: af.Collection,
         sigma=1.0,
         use_errors=True,
@@ -540,10 +559,10 @@ class AnalysisInterferometer(AnalysisDataset):
         After the non-linear search is complete create its `Result`, which includes:
 
         - The samples of the non-linear search (E.g. MCMC chains, nested sampling samples) which are used to compute
-        the maximum likelihood model, posteriors and other properties.
+          the maximum likelihood model, posteriors and other properties.
 
         - The model used to fit the data, which uses the samples to create specific instances of the model (e.g.
-        an instance of the maximum log likelihood model).
+          an instance of the maximum log likelihood model).
 
         - The non-linear search used to perform the model fit.
 
@@ -568,38 +587,38 @@ class AnalysisInterferometer(AnalysisDataset):
 
     def save_attributes_for_aggregator(self, paths: af.DirectoryPaths):
         """
-        Before the non-linear search begins, this routine saves attributes of the `Analysis` object to the `pickles`
-        folder such that they can be load after the analysis using PyAutoFit's database and aggregator tools.
+         Before the non-linear search begins, this routine saves attributes of the `Analysis` object to the `pickles`
+         folder such that they can be load after the analysis using PyAutoFit's database and aggregator tools.
 
-        For this analysis, it uses the `AnalysisDataset` object's method to output the following:
+         For this analysis, it uses the `AnalysisDataset` object's method to output the following:
 
-        - The dataset's data.
-        - The dataset's noise-map.
-        - The settings associated with the dataset.
-        - The settings associated with the inversion.
-        - The settings associated with the pixelization.
-        - The Cosmology.
-        - The hyper dataset's model image and galaxy images, if used.
+         - The dataset's data.
+         - The dataset's noise-map.
+         - The settings associated with the dataset.
+         - The settings associated with the inversion.
+         - The settings associated with the pixelization.
+         - The Cosmology.
+         - The hyper dataset's model image and galaxy images, if used.
 
-        This function also outputs attributes specific to an imaging dataset:
+         This function also outputs attributes specific to an imaging dataset:
 
-       - Its uv-wavelengths
-       - Its real space mask.
-       - The positions of the brightest pixels in the lensed source which are used to discard mass models.
-       - The preloaded image-plane source plane pixelization if used by the analysis. This ensures that differences in
-       the scikit-learn library do not lead to different pixelizations being computed if results are transferred from
-       a HPC to laptop.
+        - Its uv-wavelengths
+        - Its real space mask.
+        - The positions of the brightest pixels in the lensed source which are used to discard mass models.
+        - The preloaded image-plane source plane pixelization if used by the analysis. This ensures that differences in
+        the scikit-learn library do not lead to different pixelizations being computed if results are transferred from
+        a HPC to laptop.
 
-        It is common for these attributes to be loaded by many of the template aggregator functions given in the
-        `aggregator` modules. For example, when using the database tools to perform a fit, the default behaviour is for
-        the dataset, settings and other attributes necessary to perform the fit to be loaded via the pickle files
-        output by this function.
+         It is common for these attributes to be loaded by many of the template aggregator functions given in the
+         `aggregator` modules. For example, when using the database tools to perform a fit, the default behaviour is for
+         the dataset, settings and other attributes necessary to perform the fit to be loaded via the pickle files
+         output by this function.
 
-        Parameters
-        ----------
-        paths
-            The PyAutoFit paths object which manages all paths, e.g. where the non-linear search outputs are stored,
-            visualization, and the pickled objects used by the aggregator output by this function.
+         Parameters
+         ----------
+         paths
+             The PyAutoFit paths object which manages all paths, e.g. where the non-linear search outputs are stored,
+             visualization, and the pickled objects used by the aggregator output by this function.
         """
         super().save_attributes_for_aggregator(paths=paths)
 
