@@ -3,6 +3,7 @@ import numpy as np
 import autoarray as aa
 import autogalaxy as ag
 
+from autolens.lens.ray_tracing import Tracer
 from autolens.interferometer.fit_interferometer import FitInterferometer
 from autolens.analysis.result import ResultDataset
 
@@ -13,10 +14,10 @@ class ResultInterferometer(ResultDataset):
     this `ResultInterferometer` object, which includes:
 
     - The samples of the non-linear search (E.g. MCMC chains, nested sampling samples) which are used to compute
-    the maximum likelihood model, posteriors and other properties.
+      the maximum likelihood model, posteriors and other properties.
 
     - The model used to fit the data, which uses the samples to create specific instances of the model (e.g.
-    an instance of the maximum log likelihood model).
+      an instance of the maximum log likelihood model).
 
     - The non-linear search used to perform the model fit.
 
@@ -47,7 +48,19 @@ class ResultInterferometer(ResultDataset):
         non-linear search.
         """
         return self.analysis.fit_interferometer_via_instance_from(
-            instance=self.instance
+            instance=self.instance_copy
+        )
+
+    @property
+    def max_log_likelihood_tracer(self) -> Tracer:
+        """
+        An instance of a `Tracer` corresponding to the maximum log likelihood model inferred by the non-linear search.
+
+        The `Tracer` is computed from the `max_log_likelihood_fit`, as this ensures that all linear light profiles
+        are converted to normal light profiles with their `intensity` values updated.
+        """
+        return (
+            self.max_log_likelihood_fit.model_obj_linear_light_profiles_to_light_profiles
         )
 
     @property
