@@ -22,6 +22,7 @@ class FitInterferometerPlotter(Plotter):
         mat_plot_2d: aplt.MatPlot2D = aplt.MatPlot2D(),
         visuals_2d: aplt.Visuals2D = aplt.Visuals2D(),
         include_2d: aplt.Include2D = aplt.Include2D(),
+        residuals_symmetric_cmap: bool = True,
     ):
         """
         Plots the attributes of `FitInterferometer` objects using the matplotlib method `imshow()` and many
@@ -52,6 +53,9 @@ class FitInterferometerPlotter(Plotter):
             Contains 2D visuals that can be overlaid on 2D plots.
         include_2d
             Specifies which attributes of the `FitInterferometer` are extracted and plotted as visuals for 2D plots.
+        residuals_symmetric_cmap
+            If true, the `residual_map` and `normalized_residual_map` are plotted with a symmetric color map such
+            that `abs(vmin) = abs(vmax)`.
         """
         super().__init__(
             mat_plot_1d=mat_plot_1d,
@@ -73,6 +77,7 @@ class FitInterferometerPlotter(Plotter):
             mat_plot_2d=self.mat_plot_2d,
             include_2d=self.include_2d,
             visuals_2d=self.visuals_2d,
+            residuals_symmetric_cmap=residuals_symmetric_cmap,
         )
 
         self.subplot = self._fit_interferometer_meta_plotter.subplot
@@ -88,7 +93,7 @@ class FitInterferometerPlotter(Plotter):
 
     @property
     def tracer(self) -> Tracer:
-        return self.fit.tracer
+        return self.fit.tracer_linear_light_profiles_to_light_profiles
 
     @property
     def tracer_plotter(self) -> TracerPlotter:
@@ -157,39 +162,39 @@ class FitInterferometerPlotter(Plotter):
         Parameters
         ----------
         visibilities
-            Whether or not to make a 2D plot (via `scatter`) of the visibility data.
+            Whether to make a 2D plot (via `scatter`) of the visibility data.
         noise_map
-            Whether or not to make a 2D plot (via `scatter`) of the noise-map.
+            Whether to make a 2D plot (via `scatter`) of the noise-map.
         signal_to_noise_map
-            Whether or not to make a 2D plot (via `scatter`) of the signal-to-noise-map.
+            Whether to make a 2D plot (via `scatter`) of the signal-to-noise-map.
         model_visibilities
-            Whether or not to make a 2D plot (via `scatter`) of the model visibility data.
+            Whether to make a 2D plot (via `scatter`) of the model visibility data.
         residual_map_real
-            Whether or not to make a 1D plot (via `plot`) of the real component of the residual map.
+            Whether to make a 1D plot (via `plot`) of the real component of the residual map.
         residual_map_imag
-            Whether or not to make a 1D plot (via `plot`) of the imaginary component of the residual map.
+            Whether to make a 1D plot (via `plot`) of the imaginary component of the residual map.
         normalized_residual_map_real
-            Whether or not to make a 1D plot (via `plot`) of the real component of the normalized residual map.
+            Whether to make a 1D plot (via `plot`) of the real component of the normalized residual map.
         normalized_residual_map_imag
-            Whether or not to make a 1D plot (via `plot`) of the imaginary component of the normalized residual map.
+            Whether to make a 1D plot (via `plot`) of the imaginary component of the normalized residual map.
         chi_squared_map_real
-            Whether or not to make a 1D plot (via `plot`) of the real component of the chi-squared map.
+            Whether to make a 1D plot (via `plot`) of the real component of the chi-squared map.
         chi_squared_map_imag
-            Whether or not to make a 1D plot (via `plot`) of the imaginary component of the chi-squared map.
+            Whether to make a 1D plot (via `plot`) of the imaginary component of the chi-squared map.
         image
-            Whether or not to make a 2D plot (via `imshow`) of the source-plane image.
+            Whether to make a 2D plot (via `imshow`) of the source-plane image.
         dirty_image
-            Whether or not to make a 2D plot (via `imshow`) of the dirty image.
+            Whether to make a 2D plot (via `imshow`) of the dirty image.
         dirty_noise_map
-            Whether or not to make a 2D plot (via `imshow`) of the dirty noise map.
+            Whether to make a 2D plot (via `imshow`) of the dirty noise map.
         dirty_model_image
-            Whether or not to make a 2D plot (via `imshow`) of the dirty model image.
+            Whether to make a 2D plot (via `imshow`) of the dirty model image.
         dirty_residual_map
-            Whether or not to make a 2D plot (via `imshow`) of the dirty residual map.
+            Whether to make a 2D plot (via `imshow`) of the dirty residual map.
         dirty_normalized_residual_map
-            Whether or not to make a 2D plot (via `imshow`) of the dirty normalized residual map.
+            Whether to make a 2D plot (via `imshow`) of the dirty normalized residual map.
         dirty_chi_squared_map
-            Whether or not to make a 2D plot (via `imshow`) of the dirty chi-squared map.
+            Whether to make a 2D plot (via `imshow`) of the dirty chi-squared map.
         """
         self._fit_interferometer_meta_plotter.figures_2d(
             visibilities=visibilities,
@@ -237,23 +242,23 @@ class FitInterferometerPlotter(Plotter):
         plane_index
             The index of the plane which figures are plotted for.
         plane_image
-            Whether or not to make a 2D plot (via `imshow`) of the image of a plane in its source-plane (e.g. unlensed).
+            Whether to make a 2D plot (via `imshow`) of the image of a plane in its source-plane (e.g. unlensed).
             Depending on how the fit is performed, this could either be an image of light profiles of the reconstruction
             of an `Inversion`.
         """
         if plane_image:
 
-            if not self.tracer.planes[plane_index].has(cls=aa.pix.Pixelization):
+            if not self.tracer.planes[plane_index].has(cls=aa.Pixelization):
 
                 self.tracer_plotter.figures_2d_of_planes(
                     plane_image=True, plane_index=plane_index
                 )
 
-            elif self.tracer.planes[plane_index].has(cls=aa.pix.Pixelization):
+            elif self.tracer.planes[plane_index].has(cls=aa.Pixelization):
 
                 inversion_plotter = self.inversion_plotter_of_plane(plane_index=1)
-                inversion_plotter.figures_2d_of_mapper(
-                    mapper_index=0, reconstruction=True
+                inversion_plotter.figures_2d_of_pixelization(
+                    pixelization_index=0, reconstruction=True
                 )
 
     def subplot_fit_real_space(self):
@@ -275,10 +280,12 @@ class FitInterferometerPlotter(Plotter):
 
             inversion_plotter = self.inversion_plotter_of_plane(plane_index=1)
 
-            inversion_plotter.figures_2d_of_mapper(
-                mapper_index=0, reconstructed_image=True
+            inversion_plotter.figures_2d_of_pixelization(
+                pixelization_index=0, reconstructed_image=True
+            )
+            inversion_plotter.figures_2d_of_pixelization(
+                pixelization_index=0, reconstruction=True
             )
-            inversion_plotter.figures_2d_of_mapper(mapper_index=0, reconstruction=True)
 
             self.mat_plot_2d.output.subplot_to_figure(
                 auto_filename="subplot_fit_real_space"
