@@ -8,9 +8,7 @@ import autogalaxy as ag
 from autoconf.dictable import Dictable
 
 from autogalaxy.plane.plane import Plane
-from autogalaxy.profiles.light_profiles.light_profiles_snr import LightProfileSNR
-
-from autolens.lens.to_inversion import TracerToInversion
+from autogalaxy.profiles.light.snr import LightProfileSNR
 
 from autolens.lens import ray_tracing_util
 
@@ -158,7 +156,7 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections, Dictable):
 
         For example:
 
-        - If the input is `cls=ag.lp.LightProfile`, a list containing all light profiles in the tracer is returned.
+        - If the input is `cls=ag.LightProfile`, a list containing all light profiles in the tracer is returned.
 
         Returns
         -------
@@ -359,7 +357,7 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections, Dictable):
     def upper_plane_index_with_light_profile(self) -> int:
         return max(
             [
-                plane_index if plane.has(cls=ag.lp.LightProfile) else 0
+                plane_index if plane.has(cls=ag.LightProfile) else 0
                 for (plane_index, plane) in enumerate(self.planes)
             ]
         )
@@ -367,7 +365,7 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections, Dictable):
     @property
     def plane_indexes_with_pixelizations(self):
         plane_indexes_with_inversions = [
-            plane_index if plane.has(cls=aa.pix.Pixelization) else None
+            plane_index if plane.has(cls=aa.Pixelization) else None
             for (plane_index, plane) in enumerate(self.planes)
         ]
         return [
@@ -412,8 +410,18 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections, Dictable):
         return contribution_map_list
 
     @property
-    def to_inversion(self):
-        return TracerToInversion(tracer=self)
+    def perform_inversion(self) -> bool:
+        """
+        Returns a bool specifying whether this fit object performs an inversion.
+
+        This is based on whether any of the galaxies in the `model_obj` have a `Pixelization` or `LightProfileLinear`
+        object, in which case an inversion is performed.
+
+        Returns
+        -------
+            A bool which is True if an inversion is performed.
+        """
+        return any(plane.perform_inversion for plane in self.planes)
 
     def extract_attribute(self, cls, attr_name):
         """
@@ -425,7 +433,7 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections, Dictable):
 
         would return:
 
-        ValuesIrregular(values=[axis_ratio_0, axis_ratio_1])
+        ArrayIrregular(values=[axis_ratio_0, axis_ratio_1])
 
         If the image plane has has two galaxies with two mass profiles and the source plane another galaxy with a
         mass profile, the following:
@@ -456,9 +464,9 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections, Dictable):
         if attributes == []:
             return None
         elif isinstance(attributes[0], float):
-            return aa.ValuesIrregular(values=attributes)
+            return aa.ArrayIrregular(values=attributes)
         elif isinstance(attributes[0], tuple):
-            return aa.Grid2DIrregular(grid=attributes)
+            return aa.Grid2DIrregular(values=attributes)
 
     def extract_attributes_of_planes(self, cls, attr_name, filter_nones=False):
         """
@@ -472,7 +480,7 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections, Dictable):
 
         would return:
 
-        [ValuesIrregular(values=[axis_ratio_0]), ValuesIrregular(values=[axis_ratio_1])]
+        [ArrayIrregular(values=[axis_ratio_0]), ArrayIrregular(values=[axis_ratio_1])]
 
         If the image plane has two galaxies with a mass profile each and the source plane another galaxy with a
         mass profile, the following:
@@ -482,8 +490,8 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections, Dictable):
         would return:
 
         [
-            Grid2DIrregular(grid=[(centre_y_0, centre_x_0)]),
-            Grid2DIrregular(grid=[(centre_y_0, centre_x_0), (centre_y_1, centre_x_1)])
+            Grid2DIrregular(values=[(centre_y_0, centre_x_0)]),
+            Grid2DIrregular(values=[(centre_y_0, centre_x_0), (centre_y_1, centre_x_1)])
         ]
 
         If a Profile does not have a certain entry, it is replaced with a None, although the nones can be removed
@@ -519,7 +527,7 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections, Dictable):
 
         would return:
 
-        [ValuesIrregular(values=[axis_ratio_0]), ValuesIrregular(values=[axis_ratio_1])]
+        [ArrayIrregular(values=[axis_ratio_0]), ArrayIrregular(values=[axis_ratio_1])]
 
         If the image plane has two galaxies with a mass profile each and the source plane another galaxy with a
         mass profile, the following:
@@ -529,18 +537,18 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections, Dictable):
         would return:
 
         [
-            Grid2DIrregular(grid=[(centre_y_0, centre_x_0)]),
-            Grid2DIrregular(grid=[(centre_y_0, centre_x_0)])
-            Grid2DIrregular(grid=[(centre_y_0, centre_x_0)])
+            Grid2DIrregular(values=[(centre_y_0, centre_x_0)]),
+            Grid2DIrregular(values=[(centre_y_0, centre_x_0)])
+            Grid2DIrregular(values=[(centre_y_0, centre_x_0)])
         ]
 
         If the first galaxy in the image plane in the example above had two mass profiles as well as the galaxy in the
         source plane it would return:
 
                 [
-            Grid2DIrregular(grid=[(centre_y_0, centre_x_0), (centre_y_1, centre_x_1)]),
-            Grid2DIrregular(grid=[(centre_y_0, centre_x_0)])
-            Grid2DIrregular(grid=[(centre_y_0, centre_x_0, (centre_y_1, centre_x_1))])
+            Grid2DIrregular(values=[(centre_y_0, centre_x_0), (centre_y_1, centre_x_1)]),
+            Grid2DIrregular(values=[(centre_y_0, centre_x_0)])
+            Grid2DIrregular(values=[(centre_y_0, centre_x_0, (centre_y_1, centre_x_1))])
         ]
 
         If a Profile does not have a certain entry, it is replaced with a None, although the nones can be removed
@@ -602,8 +610,33 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections, Dictable):
         grid: aa.type.Grid2DLike,
         exposure_time: float,
         background_sky_level: float = 0.0,
+        psf: Optional[aa.Kernel2D] = None,
     ):
+        """
+        Iterate over every `LightProfileSNR` in the tracer and set their `intensity` values to values which give
+        their input `signal_to_noise_ratio` value, which is performed as follows:
 
+        - Evaluate the image of each light profile on the input grid.
+        - Blur this image with a PSF, if included.
+        - Take the value of the brightest pixel.
+        - Use an input `exposure_time` and `background_sky` (e.g. from the `SimulatorImaging` object) to determine
+          what value of `intensity` gives the desired signal to noise ratio for the image.
+
+        The intensity is set using an input grid, meaning that for strong lensing calculations the ray-traced grid
+        can be used such that the S/N accounts for the magnification of a source galaxy.
+
+        Parameters
+        ----------
+        grid
+            The (y, x) coordinates in the original reference frame of the grid.
+        exposure_time
+            The exposure time of the simulated imaging.
+        background_sky_level
+            The level of the background sky of the simulated imaging.
+        psf
+            The psf of the simulated imaging which can change the S/N of the light profile due to spreading out
+            the emission.
+        """
         grid = aa.Grid2D.uniform(
             shape_native=grid.shape_native, pixel_scales=grid.pixel_scales, sub_size=1
         )
@@ -612,12 +645,13 @@ class Tracer(ABC, ag.OperateImageGalaxies, ag.OperateDeflections, Dictable):
 
         for plane_index, plane in enumerate(self.planes):
             for galaxy in plane.galaxies:
-                for light_profile in galaxy.cls_list_from(cls=ag.lp.LightProfile):
+                for light_profile in galaxy.cls_list_from(cls=ag.LightProfile):
                     if isinstance(light_profile, LightProfileSNR):
                         light_profile.set_intensity_from(
                             grid=traced_grids_of_planes_list[plane_index],
                             exposure_time=exposure_time,
                             background_sky_level=background_sky_level,
+                            psf=psf,
                         )
 
     @aa.profile_func
