@@ -23,16 +23,19 @@ class SubhaloResult:
 
     @property
     def fit_imaging_before(self):
-        return _fit_imaging_from(
-            fit=self.result_no_subhalo,
-            galaxies=self.result_no_subhalo.instance.galaxies,
-        )
+        try:
+            return _fit_imaging_from(
+                fit=self.result_no_subhalo,
+                galaxies=self.result_no_subhalo.instance.galaxies,
+            )
+        except AttributeError:
+            return self.result_no_subhalo.max_log_likelihood_fit
 
     def _subhalo_array_from(self, values_native) -> aa.Array2D:
 
         values_reshaped = [value for values in values_native for value in values]
 
-        return aa.Array2D.manual_yx_and_values(
+        return aa.Array2D.from_yx_and_values(
             y=[centre[0] for centre in self.grid_search_result.physical_centres_lists],
             x=[centre[1] for centre in self.grid_search_result.physical_centres_lists],
             values=values_reshaped,
@@ -47,15 +50,20 @@ class SubhaloResult:
         relative_to_no_subhalo: bool = True,
     ) -> aa.Array2D:
 
+        try:
+            samples_no_subhalo = self.result_no_subhalo["samples"]
+        except TypeError:
+            samples_no_subhalo = self.result_no_subhalo.samples
+
         if (not use_log_evidences) and (not use_stochastic_log_likelihoods):
 
             values_native = self.grid_search_result.log_likelihoods_native
             values_native[values_native == None] = np.nan
 
             if relative_to_no_subhalo:
-                values_native -= self.result_no_subhalo[
-                    "samples"
-                ].max_log_likelihood_sample.log_likelihood
+                values_native -= (
+                    samples_no_subhalo.max_log_likelihood_sample.log_likelihood
+                )
 
         elif use_log_evidences and not use_stochastic_log_likelihoods:
 
@@ -63,7 +71,7 @@ class SubhaloResult:
             values_native[values_native == None] = np.nan
 
             if relative_to_no_subhalo:
-                values_native -= self.result_no_subhalo["samples"].log_evidence
+                values_native -= samples_no_subhalo.log_evidence
 
         else:
 
@@ -89,9 +97,7 @@ class SubhaloResult:
 
     def instance_list_via_results_from(self, results):
         return [
-            None
-            if result.samples.median_pdf_instance is None
-            else result.samples.median_pdf_instance
+            None if result.samples.median_pdf() is None else result.samples.median_pdf()
             for result in results
         ]
 
@@ -110,7 +116,7 @@ class SubhaloResult:
         )
 
     @property
-    def centres_native(self) -> List[Tuple[float]]:
+    def centres_native(self) -> aa.Grid2D:
 
         instance_list = self.instance_list_via_results_from(
             results=self.grid_search_result.results
@@ -134,8 +140,8 @@ class SubhaloResult:
             ]
         )
 
-        return aa.Grid2D.manual_native(
-            grid=centres_native,
+        return aa.Grid2D.no_mask(
+            values=centres_native,
             pixel_scales=self.grid_search_result.physical_step_sizes,
         )
 
@@ -313,7 +319,7 @@ class SubhaloPlotter(AbstractPlotter):
 
         self.set_title("Source Reconstruction (No Subhalo)")
         self.fit_imaging_before_plotter.figures_2d_of_planes(
-            plane_image=True, plane_index=1
+            plane_index=1, plane_image=True
         )
 
         self.set_title("Normailzed Residuals (With Subhalo)")
@@ -324,7 +330,7 @@ class SubhaloPlotter(AbstractPlotter):
 
         self.set_title("Source Reconstruction (With Subhalo)")
         self.fit_imaging_detect_plotter.figures_2d_of_planes(
-            plane_image=True, plane_index=1
+            plane_index=1, plane_image=True
         )
 
         self.mat_plot_2d.output.subplot_to_figure(
