@@ -5,7 +5,7 @@ from autofit.non_linear.mcmc.emcee.plotter import EmceePlotter
 from autofit.non_linear.mcmc.zeus.plotter import ZeusPlotter
 from autofit.non_linear.optimize.pyswarms.plotter import PySwarmsPlotter
 
-from autoarray.plot.wrap.wrap_base import (
+from autoarray.plot.wrap.base import (
     Units,
     Figure,
     Axis,
@@ -19,11 +19,12 @@ from autoarray.plot.wrap.wrap_base import (
     YLabel,
     XLabel,
     Legend,
+    Annotate,
     Text,
     Output,
 )
-from autoarray.plot.wrap.wrap_1d import YXPlot, FillBetween
-from autoarray.plot.wrap.wrap_2d import (
+from autoarray.plot.wrap.one_d import YXPlot, FillBetween
+from autoarray.plot.wrap.two_d import (
     ArrayOverlay,
     GridScatter,
     GridPlot,
@@ -35,7 +36,7 @@ from autoarray.plot.wrap.wrap_2d import (
     BorderScatter,
     PositionsScatter,
     IndexScatter,
-    PixelizationGridScatter,
+    MeshGridScatter,
     ParallelOverscanPlot,
     SerialPrescanPlot,
     SerialOverscanPlot,
@@ -53,19 +54,24 @@ from autoarray.dataset.plot.interferometer_plotters import InterferometerPlotter
 from autoarray.plot.multi_plotters import MultiFigurePlotter
 from autoarray.plot.multi_plotters import MultiYX1DPlotter
 
-from autogalaxy.plot.mat_wrap.wrap import (
+from autogalaxy.plot.wrap import (
     HalfLightRadiusAXVLine,
     EinsteinRadiusAXVLine,
     LightProfileCentresScatter,
     MassProfileCentresScatter,
-    CriticalCurvesPlot,
-    CausticsPlot,
+    TangentialCriticalCurvesPlot,
+    TangentialCausticsPlot,
+    RadialCriticalCurvesPlot,
+    RadialCausticsPlot,
     MultipleImagesScatter,
 )
 
-from autogalaxy.plot.mat_wrap.mat_plot import MatPlot1D, MatPlot2D
-from autogalaxy.plot.mat_wrap.include import Include1D, Include2D
-from autogalaxy.plot.mat_wrap.visuals import Visuals1D, Visuals2D
+from autogalaxy.plot.mat_plot.one_d import MatPlot1D
+from autogalaxy.plot.mat_plot.two_d import MatPlot2D
+from autogalaxy.plot.include.one_d import Include1D
+from autogalaxy.plot.include.two_d import Include2D
+from autogalaxy.plot.visuals.one_d import Visuals1D
+from autogalaxy.plot.visuals.two_d import Visuals2D
 
 from autogalaxy.profiles.plot.light_profile_plotters import LightProfilePlotter
 from autogalaxy.profiles.plot.light_profile_plotters import LightProfilePDFPlotter
@@ -90,3 +96,4 @@ from autolens.interferometer.plot.fit_interferometer_plotters import (
 )
 from autolens.point.plot.fit_point_plotters import FitPointDatasetPlotter
 from autolens.lens.plot.ray_tracing_plotters import TracerPlotter
+from autolens.lens.subhalo import SubhaloPlotter
