@@ -9,7 +9,7 @@ class AbstractFitPositionsSourcePlane:
     def __init__(
         self,
         positions: aa.Grid2DIrregular,
-        noise_map: aa.ValuesIrregular,
+        noise_map: aa.ArrayIrregular,
         tracer: Tracer,
     ):
         """
@@ -20,7 +20,7 @@ class AbstractFitPositionsSourcePlane:
         value in different ways.
 
         Parameters
-        -----------
+        ----------
         positions : Grid2DIrregular
             The (y,x) arc-second coordinates of named positions which the log_likelihood is computed using. Positions
             are paired to galaxies in the `Tracer` using their names.
@@ -36,7 +36,7 @@ class AbstractFitPositionsSourcePlane:
         ]
 
     @property
-    def furthest_separations_of_source_plane_positions(self) -> aa.ValuesIrregular:
+    def furthest_separations_of_source_plane_positions(self) -> aa.ArrayIrregular:
         """
         Returns the furthest distance of every source-plane (y,x) coordinate to the other source-plane (y,x)
         coordinates.
@@ -51,7 +51,7 @@ class AbstractFitPositionsSourcePlane:
 
         Returns
         -------
-        aa.ValuesIrregular
+        aa.ArrayIrregular
             The further distances of every set of grouped source-plane coordinates the other source-plane coordinates
             that it is grouped with.
         """
@@ -69,14 +69,14 @@ class FitPositionsSourceMaxSeparation(AbstractFitPositionsSourcePlane):
     def __init__(
         self,
         positions: aa.Grid2DIrregular,
-        noise_map: Optional[aa.ValuesIrregular],
+        noise_map: Optional[aa.ArrayIrregular],
         tracer: Tracer,
     ):
         """A lens position fitter, which takes a set of positions (e.g. from a plane in the tracer) and computes \
         their maximum separation, such that points which tracer closer to one another have a higher log_likelihood.
 
         Parameters
-        -----------
+        ----------
         positions : Grid2DIrregular
             The (y,x) arc-second coordinates of positions which the maximum distance and log_likelihood is computed using.
         noise_value
