@@ -17,7 +17,7 @@ class FitPositionsImage(aa.FitDataset):
         self,
         name: str,
         positions: aa.Grid2DIrregular,
-        noise_map: aa.ValuesIrregular,
+        noise_map: aa.ArrayIrregular,
         tracer: Tracer,
         point_solver: PointSolver,
         point_profile: Optional[ag.ps.Point] = None,
@@ -27,7 +27,7 @@ class FitPositionsImage(aa.FitDataset):
         their maximum separation, such that points which tracer closer to one another have a higher log_likelihood.
 
         Parameters
-        -----------
+        ----------
         positions : Grid2DIrregular
             The (y,x) arc-second coordinates of positions which the maximum distance and log_likelihood is computed using.
         noise_value
@@ -96,8 +96,17 @@ class FitPositionsImage(aa.FitDataset):
         return self.model_data
 
     @property
-    def residual_map(self) -> aa.ValuesIrregular:
+    def residual_map(self) -> aa.ArrayIrregular:
 
         residual_positions = self.positions - self.model_positions
 
         return residual_positions.distances_to_coordinate_from(coordinate=(0.0, 0.0))
+
+    @property
+    def chi_squared(self) -> float:
+        """
+        Returns the chi-squared terms of the model data's fit to an dataset, by summing the chi-squared-map.
+        """
+        return ag.util.fit.chi_squared_from(
+            chi_squared_map=self.chi_squared_map,
+        )
