@@ -13,7 +13,7 @@ class FitPositionsSource(aa.FitDataset):
         self,
         name: str,
         positions: aa.Grid2DIrregular,
-        noise_map: aa.ValuesIrregular,
+        noise_map: aa.ArrayIrregular,
         tracer: Tracer,
         point_profile: Optional[ag.ps.Point] = None,
     ):
@@ -22,7 +22,7 @@ class FitPositionsSource(aa.FitDataset):
         their maximum separation, such that points which tracer closer to one another have a higher log_likelihood.
 
         Parameters
-        -----------
+        ----------
         positions : Grid2DIrregular
             The (y,x) arc-second coordinates of positions which the maximum distance and log_likelihood is computed using.
         noise_value
@@ -92,8 +92,17 @@ class FitPositionsSource(aa.FitDataset):
         return self.model_data
 
     @property
-    def residual_map(self) -> aa.ValuesIrregular:
+    def residual_map(self) -> aa.ArrayIrregular:
 
         return self.model_positions.distances_to_coordinate_from(
             coordinate=self.source_plane_coordinate
         )
+
+    @property
+    def chi_squared(self) -> float:
+        """
+        Returns the chi-squared terms of the model data's fit to an dataset, by summing the chi-squared-map.
+        """
+        return ag.util.fit.chi_squared_from(
+            chi_squared_map=self.chi_squared_map,
+        )
