@@ -99,7 +99,7 @@ class AnalysisPoint(af.Analysis, AnalysisLensing):
 
     def make_result(
         self,
-        samples: af.PDFSamples,
+        samples: af.SamplesPDF,
         model: af.Collection,
         sigma=1.0,
         use_errors=True,
