@@ -37,7 +37,9 @@ class AbstractPointSolver:
             if magnification > self.magnification_threshold:
                 grid_mag.append(grid[index, :])
 
-        return aa.Grid2DIrregularUniform(grid=grid_mag, pixel_scales=grid.pixel_scales)
+        return aa.Grid2DIrregularUniform(
+            values=grid_mag, pixel_scales=grid.pixel_scales
+        )
 
     def grid_with_coordinates_to_mass_profile_centre_removed_from(
         self, lensing_obj, grid
@@ -82,7 +84,7 @@ class AbstractPointSolver:
                     outside_distance=self.distance_to_mass_profile_centre,
                 )
 
-            return aa.Grid2DIrregularUniform(grid=grid, pixel_scales=pixel_scales)
+            return aa.Grid2DIrregularUniform(values=grid, pixel_scales=pixel_scales)
 
         return grid
 
@@ -133,7 +135,7 @@ class AbstractPointSolver:
         )
 
         return aa.Grid2DIrregularUniform(
-            grid=grid_buffed,
+            values=grid_buffed,
             pixel_scales=(
                 pixel_scales[0] / upscale_factor,
                 pixel_scales[1] / upscale_factor,
@@ -146,10 +148,10 @@ class AbstractPointSolver:
         traces closer to the input (y,x) source-plane coordinate than any of its 8 adjacent neighbors. This is
         performed by:
 
-         1) Computing the deflection angle of every (y,x) coordinate on the grid using the input lensing object.
-         2) Ray tracing these coordinates to the source-plane.
-         3) Computing their distance to the centre of the source in the source-plane.
-         4) Finding pixels whose source-plane distance is lower than all 8 neighboring pixels.
+        1) Computing the deflection angle of every (y,x) coordinate on the grid using the input lensing object.
+        2) Ray tracing these coordinates to the source-plane.
+        3) Computing their distance to the centre of the source in the source-plane.
+        4) Finding pixels whose source-plane distance is lower than all 8 neighboring pixels.
 
         The `PositionFinder` works by locating pixels that trace closer to the source galaxy than neighboring pixels
         and iteratively refining the grid to find pixels that trace close at higher and higher resolutions. This
@@ -189,7 +191,7 @@ class AbstractPointSolver:
         )
 
         return aa.Grid2DIrregularUniform(
-            grid=grid_peaks, pixel_scales=grid.pixel_scales
+            values=grid_peaks, pixel_scales=grid.pixel_scales
         )
 
     def grid_within_distance_of_source_plane_centre(
@@ -197,30 +199,30 @@ class AbstractPointSolver:
     ):
         """
         For an input grid of (y,x) coordinates, remove all coordinates that do not trace within a threshold distance
-            of the source-plane centre. This is performed by:
+        of the source-plane centre. This is performed by:
 
-             1) Computing the deflection angle of every (y,x) coordinate on the grid using the input lensing object.
-             2) Ray tracing these coordinates to the source-plane.
-             3) Computing their distance to the centre of the source in the source-plane.
-             4) Removing all coordinates that are not within the input distance of the centre.
+        1) Computing the deflection angle of every (y,x) coordinate on the grid using the input lensing object.
+        2) Ray tracing these coordinates to the source-plane.
+        3) Computing their distance to the centre of the source in the source-plane.
+        4) Removing all coordinates that are not within the input distance of the centre.
 
-            This algorithm is optionally used in the _PositionFiner_. It may be required to remove solutions that are
-            genuine 'peaks' that tracer closer to a source than their 8 neighboring pixels, but which do not truly
-            trace to the centre of the source-centre.
+        This algorithm is optionally used in the _PositionFiner_. It may be required to remove solutions that are
+        genuine 'peaks' that tracer closer to a source than their 8 neighboring pixels, but which do not truly
+        trace to the centre of the source-centre.
 
-            Parameters
-            ----------
-            lensing_obj
-                An object which has a `deflection_2d_from` method for performing lensing calculations, for example a
-                `MassProfile`, _Galaxy_, `Plane` or `Tracer`.
-            grid : autoarray.Grid2DIrregularUniform or ndarray
-                A grid of (y,x) Cartesian coordinates for which the 'peak' values that trace closer to the source than
-                their neighbors are found.
-            source_plane_coordinate : (y,x)
-                The (y,x) coordinate in the source-plane pixels that the distance of traced grid coordinates are computed
-                for.
-            distance
-                The distance within which a grid coordinate must trace to the source-plane centre to be retained.
+        Parameters
+        ----------
+        lensing_obj
+            An object which has a `deflection_2d_from` method for performing lensing calculations, for example a
+            `MassProfile`, _Galaxy_, `Plane` or `Tracer`.
+        grid
+           A grid of (y,x) Cartesian coordinates for which the 'peak' values that trace closer to the source than
+           their neighbors are found.
+        source_plane_coordinate
+           The (y,x) coordinate in the source-plane pixels that the distance of traced grid coordinates are computed
+           for.
+        distance
+           The distance within which a grid coordinate must trace to the source-plane centre to be retained.
         """
         if distance is None:
             return grid
@@ -240,7 +242,7 @@ class AbstractPointSolver:
         )
 
         return aa.Grid2DIrregularUniform(
-            grid=grid_within_distance_of_centre, pixel_scales=grid.pixel_scales
+            values=grid_within_distance_of_centre, pixel_scales=grid.pixel_scales
         )
 
 
@@ -350,8 +352,10 @@ class PointSolver(AbstractPointSolver):
             deflections_func=deflections_func,
         )
 
-        coordinates_list = self.grid_with_coordinates_to_mass_profile_centre_removed_from(
-            lensing_obj=lensing_obj, grid=coordinates_list
+        coordinates_list = (
+            self.grid_with_coordinates_to_mass_profile_centre_removed_from(
+                lensing_obj=lensing_obj, grid=coordinates_list
+            )
         )
 
         coordinates_list = self.grid_with_points_below_magnification_threshold_removed(
@@ -365,13 +369,13 @@ class PointSolver(AbstractPointSolver):
             coordinates_list = self.grid_within_distance_of_source_plane_centre(
                 deflection_func=deflections_func,
                 grid=aa.Grid2DIrregularUniform(
-                    grid=coordinates_list, pixel_scales=self.grid.pixel_scales
+                    values=coordinates_list, pixel_scales=self.grid.pixel_scales
                 ),
                 source_plane_coordinate=source_plane_coordinate,
                 distance=self.distance_to_source_centre,
             )
 
-            return aa.Grid2DIrregular(grid=coordinates_list)
+            return aa.Grid2DIrregular(values=coordinates_list)
 
         pixel_scale = self.grid.pixel_scale
 
@@ -402,7 +406,7 @@ class PointSolver(AbstractPointSolver):
         coordinates_list = self.grid_within_distance_of_source_plane_centre(
             deflection_func=deflections_func,
             grid=aa.Grid2DIrregularUniform(
-                grid=coordinates_list, pixel_scales=(pixel_scale, pixel_scale)
+                values=coordinates_list, pixel_scales=(pixel_scale, pixel_scale)
             ),
             source_plane_coordinate=source_plane_coordinate,
             distance=self.distance_to_source_centre,
@@ -414,7 +418,7 @@ class PointSolver(AbstractPointSolver):
             grid=coordinates_list,
         )
 
-        return aa.Grid2DIrregular(grid=coordinates_list)
+        return aa.Grid2DIrregular(values=coordinates_list)
 
 
 @aa.util.numba.jit()
@@ -548,7 +552,7 @@ def grid_square_neighbors_1d_from(shape_slim):
          x x x  x x x x x x x
          x x x  x x x x x x x
 
-    On the grid above, the grid cells in 1D indxes 5 and 6 have 8 neighboring pixels and their entries in the
+    On the grid above, the grid cells in 1D indexes 5 and 6 have 8 neighboring pixels and their entries in the
     grid_neighbors_1d array will be:
 
     grid_neighbors_1d[0,:] = [0, 1, 2, 4, 6, 8, 9, 10]
