@@ -1,5 +1,4 @@
 import datetime
-from typing import Any, Dict
 
 # Configuration file for the Sphinx documentation builder.
 #
@@ -16,14 +15,41 @@ from typing import Any, Dict
 
 from pyprojroot import here
 
-workspace_path = str(here())
+# /home/docs/checkouts/readthedocs.org/user_builds/pyautolens/checkouts/latest/docs
+
+clone_path = str(here())
 
 import os
 import sys
-import autolens
 
 sys.path.insert(0, os.path.abspath("."))
 
+
+def clone_repo(name: str, url: str):
+
+    clone = f"git clone {url}/{name}"
+    os.system(clone)
+    os.system(f"pip install -r {name}/requirements.txt")
+    os.system(f"rm -rf {name}/docs")
+    sys.path.insert(
+        0,
+        os.path.abspath(f"{clone_path}/{name}"),
+    )
+
+
+clone_repo(name="PyAutoFit", url="https://github.com/rhayes777")
+clone_repo(name="PyAutoArray", url="https://github.com/Jammy2211")
+clone_repo(name="PyAutoGalaxy", url="https://github.com/Jammy2211")
+
+clone_path = os.path.split(clone_path)[0]
+
+sys.path.insert(
+    0,
+    os.path.abspath(clone_path),
+)
+
+import autolens
+
 # -- Project information -----------------------------------------------------
 
 year = datetime.date.today().year
@@ -32,7 +58,7 @@ copyright = "2022, James Nightingale, Richard Hayes"
 author = "James Nightingale, Richard Hayes"
 
 # The full version, including alpha/beta/rc tags
-release = "2022.05.02.1"
+release = autolens.__version__
 master_doc = "index"
 
 
@@ -47,6 +73,7 @@ extensions = [
     "sphinx.ext.todo",
     "sphinx.ext.napoleon",
     "sphinx.ext.viewcode",
+    "sphinx_autodoc_typehints",  # Automatically document param types (less noise in class signature)
     "numpydoc",
     # External stuff
     "myst_parser",
@@ -54,6 +81,10 @@ extensions = [
     "sphinx_design",
     "sphinx_inline_tabs",
 ]
+
+set_type_checking_flag = True  # Enable 'expensive' imports for sphinx_autodoc_typehints
+add_module_names = False  # Remove namespaces from class/method signatures
+
 templates_path = ["_templates"]
 
 # -- Options for extlinks ----------------------------------------------------
@@ -77,12 +108,15 @@ myst_enable_extensions = ["colon_fence", "deflist"]
 myst_heading_anchors = 3
 
 autosummary_generate = True
+autosummary_imported_members = True
 autodoc_member_order = "bysource"
 autodoc_default_flags = ["members"]
+autodoc_class_signature = "separated"
+autoclass_content = "init"
 
 numpydoc_show_class_members = False
 numpydoc_show_inherited_class_members = False
-numpydoc_class_members_toctree = False
+nnumpydoc_class_members_toctree = True
 
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
@@ -125,13 +159,6 @@ html_theme_options = {
     }
 }
 
-if "READTHEDOCS" in os.environ:
-    html_theme_options["announcement"] = (
-        "This documentation is hosted on Read the Docs only for testing. Please use "
-        "<a href='https://pradyunsg.me/furo/'>the main documentation</a> instead."
-    )
-
-
 from sphinx.builders.html import StandaloneHTMLBuilder
 
 StandaloneHTMLBuilder.supported_image_types = ["image/gif", "image/png", "image/jpeg"]
